@@ -4,7 +4,7 @@
 export source="${BASH_SOURCE[0]}"; debug.sh source
 
 path="$( command -v bashrc )"; export path
-debug.sh "${path}"
+debug.sh path
 
 # shellcheck disable=SC1090
 if test -f "${path}"; then
