@@ -11,6 +11,7 @@ path="$( pwd )"
 name="$( basename "${path}" )"
 export path name; debug.sh path name
 
+unset VIRTUAL_ENV PYTHONHOME
 deactivate > /dev/null 2>&1
 
 if error="$( /usr/local/bin/pip3.8 install -vvvv --upgrade "${name}" 2>&1 )"; then
@@ -19,4 +20,6 @@ else
   error.sh upgrade "${name}" "${error}"; exit 1
 fi
 
+/usr/local/bin/pip3.8 install --upgrade "${name}" > /dev/null 2>&1
+
 unset source error path name
