@@ -1,7 +1,7 @@
 #!/usr/bin/env bash
 # ${1} - path
 # ${2} - bump: <major|minor>
-# ${3} - twine: <"${GITHUB_USERNAME}"|"${GITHUB_ORGANIZATION_ID}"|pypi>
+# ${3} - twine: <"${GITHUB_USERNAME}"|"${NFERX_GITHUB_USERNAME}"|pypi>
 # shellcheck disable=SC2034
 export source="${BASH_SOURCE[0]}"; debug.sh source
 
@@ -13,8 +13,9 @@ while (( "$#" )); do
   case "${1}" in
     major) bump="${1}" ;;
     minor) bump="${1}" ;;
+    patch) bump="${1}" ;;
     "${GITHUB_USERNAME}") twine="${1}" ;;
-    "${GITHUB_ORGANIZATION_ID}") twine="${1}" ;;
+    "${NFERX_GITHUB_USERNAME}") twine="${1}" ;;
     pypi) twine="${1}" ;;
     *) path="${1}";;
   esac; shift
@@ -30,11 +31,12 @@ path="$( pwd )"
 name="$( basename "${path}" )"
 export bump twine path name; debug.sh bump twine path name
 
-virtual="${path}/venv/bin"
-export virtual; debug.sh virtual
-
 if isuser.sh; then
   project-venv.sh "${path}"
+  virtual="${path}/venv/bin"
+  export virtual; debug.sh virtual
+  # shellcheck disable=SC1090
+  source "${virtual}/activate"
   project-clean.sh "${path}" || exit 1
   find "${path}" -type d -name scripts -exec chmod -R +x "{}" \;
 	gadd.sh || exit 1
@@ -61,6 +63,7 @@ if isuser.sh; then
   fi
   gmerge.sh || exit 1
   project-clean.sh "${path}" || exit 1
+  unset VIRTUAL_ENV PYTHONHOME
   deactivate > /dev/null 2>&1
   project-upgrade.sh "${name}" || exit 1
 else
